.. _trojanvision.models.torchvision:

torchvision
============

.. currentmodule:: trojanvision.models

.. autoclass:: AlexNet
   :members:

.. autoclass:: DenseNet
   :members:

.. autoclass:: EfficientNet
   :members:

.. autoclass:: MNASNet
   :members:

.. autoclass:: MobileNet
   :members:

.. autoclass:: ResNet
   :members:

.. autoclass:: ShuffleNetV2
   :members:

.. autoclass:: VGG
   :members:
